<?php
/*
Widget Name: comicpress archive dropdown
Widget URI: http://comicpress.org/
Description: 
Author: Philip M. Hofer (Frumph)
Version: 1.04
Author URI: http://webcomicplanet.com/

*/

class widget_comicpress_archive_dropdown extends WP_Widget {
	
	function widget_comicpress_archive_dropdown() {
		$widget_ops = array('classname' => 'widget_comicpress_archive_dropdown', 'description' => __('Display a dropdown list of your archives, styled.','comicpress') );
		$this->WP_Widget('archive_dropdown', __('ComicPress Archive Dropdown','comicpress'), $widget_ops);
	}
	
	function widget($args, $instance) {
		global $post, $wp_query; 
		$temp_post = $post; 
		$temp_query = $wp_query;
		extract($args, EXTR_SKIP); 
		
		echo $before_widget;
		$title = empty($instance['title']) ? '' : apply_filters('widget_title', $instance['title']); 
		if ( !empty( $title ) ) { echo $before_title . $title . $after_title; };
		?>
		<div class="archive-dropdown-wrap">
		<select name="archive-dropdown" class="archive-dropdown" onchange='document.location.href=this.options[this.selectedIndex].value;'> 
		<option value=""><?php echo attribute_escape(__('Archives...','comicpress')); ?></option> 
		<?php
		switch ($instance['mode']) {
			case "monthly":
				wp_get_archives('type=monthly&format=option&show_post_count=-1');
				break;
			case "yearly":
				wp_get_archives('type=yearly&format=option&show_post_count=-1');
				break;
			case "allposts":
				wp_get_archives('type=postbypost&format=option&show_post_count=-1');
				break;
			case "blogposts":
				$comicArchive = new WP_Query(); $comicArchive->query('showposts=-1&cat=-'.exclude_comic_categories());
				while ($comicArchive->have_posts()) : $comicArchive->the_post() ?>
					<option value="<?php echo get_permalink($post->ID) ?>"><?php the_title(); ?></option>
					<?php endwhile;
				break;				
			case "comicposts":
				$comicArchive = new WP_Query(); $comicArchive->query('showposts=-1&cat='.get_all_comic_categories_as_cat_string());
				while ($comicArchive->have_posts()) : $comicArchive->the_post() ?>
					<option value="<?php echo get_permalink($post->ID) ?>"><?php the_title(); ?></option>
					<?php endwhile;
				break;
			case "allcats":
				$args=array('hide_empty' => 1, 'order_by' => 'group');
				$categories=  get_categories($args); 
				foreach ($categories as $cat) {
					if ($cat->category_count > 0) {
						$option = '<option value="/category/archives/'.$cat->category_nicename.'">';
						$option .= $cat->cat_name;
						$option .= ' ('.$cat->category_count.')';
						$option .= '</option>';
						echo $option;
					}
				}
				break;
			case "blogcats":
				$args=array('hide_empty' => 1, 'order_by' => 'group', 'exclude' => get_all_comic_categories_as_cat_string());
				$categories=  get_categories($args); 
				foreach ($categories as $cat) {
					if ($cat->category_count > 0) {
						$option = '<option value="/category/archives/'.$cat->category_nicename.'">';
						$option .= $cat->cat_name;
						$option .= ' ('.$cat->category_count.')';
						$option .= '</option>';
						echo $option;
					}
				}
				break;
			case "comiccats":
			default:
				$args=array('hierarchical ' => 1, 'order_by' => 'group', 'include' => get_all_comic_categories_as_cat_string());
				$categories=  get_categories($args); 
				foreach ($categories as $cat) {
					if ($cat->category_count > 0) {
						$option = '<option value="/category/archives/'.$cat->category_nicename.'">';
						$option .= $cat->cat_name;
						$option .= ' ('.$cat->category_count.')';
						$option .= '</option>';
						echo $option;
					}
				}
				break;
		}
		?>
		</select>
		</div>
		<?php
		echo $after_widget;
		$post = $temp_post; $temp_post = null;
		$wp_query = $temp_query; $temp_query = null;
	}
	
	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['mode'] = strip_tags($new_instance['mode']);
		$instance['count'] = strip_tags($new_instance['count']);
		return $instance;
	}
	
	function form($instance) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'mode' => 'monthly', 'count' => '-1' ) );
		$title = strip_tags($instance['title']);
		$mode = strip_tags($instance['mode']);
		$count = strip_tags($instance['count']);
		?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:','comicpress'); ?> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo attribute_escape($title); ?>" /></label></p>
		<hr>
		<p>
		<label for="<?php echo $this->get_field_id('mode'); ?>-monthly"><input id="<?php echo $this->get_field_id('mode'); ?>-monthly" name="<?php echo $this->get_field_name('mode'); ?>" type="radio" value="monthly" <?php checked('monthly', $mode); ?> /><?php _e('Monthly','comicpress'); ?></label><br />
		<label for="<?php echo $this->get_field_id('mode'); ?>-yearly"><input id="<?php echo $this->get_field_id('mode'); ?>-yearly" name="<?php echo $this->get_field_name('mode'); ?>" type="radio" value="yearly" <?php checked('yearly', $mode); ?> /><?php _e('Yearly','comicpress'); ?></label><br />
		<hr>
		<label for="<?php echo $this->get_field_id('mode'); ?>-allposts"><input id="<?php echo $this->get_field_id('mode'); ?>-allposts" name="<?php echo $this->get_field_name('mode'); ?>" type="radio" value="allposts" <?php checked('allposts', $mode); ?> /><?php _e('All Posts','comicpress'); ?></label><br />
		<label for="<?php echo $this->get_field_id('mode'); ?>-blogposts"><input id="<?php echo $this->get_field_id('mode'); ?>-blogposts" name="<?php echo $this->get_field_name('mode'); ?>" type="radio" value="blogposts" <?php checked('blogposts', $mode); ?> /><?php _e('Blog Posts','comicpress'); ?></label><br />
		<label for="<?php echo $this->get_field_id('mode'); ?>-comicposts"><input id="<?php echo $this->get_field_id('mode'); ?>-comicposts" name="<?php echo $this->get_field_name('mode'); ?>" type="radio" value="comicposts" <?php checked('comicposts', $mode); ?> /><?php _e('Comic Posts','comicpress'); ?></label><br />
		<hr>
		<label for="<?php echo $this->get_field_id('mode'); ?>-allcats"><input id="<?php echo $this->get_field_id('mode'); ?>-allcats" name="<?php echo $this->get_field_name('mode'); ?>" type="radio" value="allcats" <?php checked('allcats', $mode); ?> /><?php _e('All Categories','comicpress'); ?></label><br />
		<label for="<?php echo $this->get_field_id('mode'); ?>-blogcats"><input id="<?php echo $this->get_field_id('mode'); ?>-blogcats" name="<?php echo $this->get_field_name('mode'); ?>" type="radio" value="blogcats" <?php checked('blogcats', $mode); ?> /><?php _e('Blog Categories','comicpress'); ?></label><br />
		<label for="<?php echo $this->get_field_id('mode'); ?>-comiccats"><input id="<?php echo $this->get_field_id('mode'); ?>-comiccats" name="<?php echo $this->get_field_name('mode'); ?>" type="radio" value="comiccats" <?php checked('comiccats', $mode); ?> /><?php _e('Comic Categories','comicpress'); ?></label><br />
		</p>
		<?php
	}
}
register_widget('widget_comicpress_archive_dropdown');


function widget_comicpress_archive_dropdown_init() {    
	new widget_comicpress_archive_dropdown(); 
} 

add_action('widgets_init', 'widget_comicpress_archive_dropdown_init');



?>